# ==================================================================
# Gossamer Community
#
#   Website  : http://gossamer-threads.com/
#   Support  : http://gossamer-threads.com/scripts/support/
#   CVS Info :
#   Revision : $Id: SSI.pm,v 1.24 2005/07/21 23:18:26 alex Exp $
#
# Copyright (c) 2004 Gossamer Threads Inc.  All Rights Reserved.
# Redistribution in part or in whole strictly prohibited. Please
# see LICENSE file for full details.
# ==================================================================

package Community::Web::LSSI;
# ===================================================================
    use strict;
    use Community qw/
        $IN $DB $CFG
        comm_language
    /;
    use Community::Web::SSI;
    use GT::Template;

sub ssi_profile_form {
# -------------------------------------------------------------------
    require GT::SQL::Display::HTML;
    require GT::SQL::Display::HTML::Table;

    my $opts    = ref $_[0] ? shift : {@_};

    $opts->{table}      ||= 'comm_users';
    $opts->{template}   ||= 'user_form_edit.html';
    $opts->{col_prefix} ||= '^prof_'; # used to filter columns
    $opts->{required}   ||= '*';
    $opts->{id}         ||= '';
    $opts->{css}        ||= 1;
    $opts->{class}      ||= '';
    $opts->{show_all_fields} ||= 0; # ignore sign_restricted_profile?
    $opts->{t} ||= $CFG->{system_template_set};

    my $user_tb = $DB->table($opts->{table});

# Take the list of restricted profile fields
# and convert it into a hashref that can be used as a lookup
# to quickly determine matches, but check to see that
# the system isn't being requested to display all possible profile
# fields
    my $restricted_fields = $opts->{show_all_fields} ?
        {} :
        { map {($_=>1)} @{$CFG->{signup_restricted_profile}} };

# Choose which columns will be displayed.
    unless ( $opts->{cols} ) {
        my $cols = $opts->{cols} = [];
        my $skip = { map {($_=>1)} @{$opts->{col_skip}||[]} };

        foreach  ( $user_tb->ordered_columns ) {
            next if $restricted_fields->{$_};
            next unless /$opts->{col_prefix}/;
            next if $skip->{$_};
            push @$cols, $_;
        }

        $opts->{cols} = $cols;
    }

    my $tags    = GT::Template->tags;
    my $cols    = {$user_tb->cols}; # request a copy of the def
    my $disp    = $DB->html($user_tb, GT::Template->tags);
    my $html    = '';

    if ( $opts->{mode} eq 'hidden' ) {

# Preserve all columns that relate to the comm_user database
        my $cols        = $user_tb->cols;
        my $hidden_html = '';
        foreach my $col ( keys %$cols ) {
            foreach my $name ( map { "$col$_" } ( '', qw( -opt -gt -lt -le -ge -ne )) ) {
                my $v = $tags->{$name};
                next unless defined $v;
                my $input_html = ssi_form_control({
                    form_type => 'hidden',
                    value     => $v,
                    name      => $name
                });
                $html .= $$input_html;
            }
        }
        return \$html;
    }
    foreach my $col (@{$opts->{cols}}) {

        my $control_opts        = $cols->{$col}||{};

        my $title               = comm_language( $cols->{$col}{form_display} );

        my $input_html = Community::Web::SSI::ssi_form_control({
            name      => $col,
            def       => $control_opts,
            value     => $tags->{$col}
        });

        if ($opts->{css}) {
            if ($$input_html =~ /type="text"/) {
                my $replace = qq~ id="$title" class="text"\\>~;
                $$input_html =~ s/>/$replace/;
            }
        }
        $CFG->{required}   = $cols->{$col}->{not_null} ? $opts->{required} : undef;
        $CFG->{title}      = $title;
        $CFG->{input_html} = $$input_html;
        $html .= GT::Template->parse($CFG->{path_private}.'/templates/'.$opts->{t}.'/'.$opts->{template}, $CFG);
    }
    if ($IN->param('do') eq 'ssi_profile_form') {
        print $IN->header() unless ($IN->param('noheaders'));
        print $html;
    }
    else {
        return \$html;
    }
}

sub ssi_apps_form {
# -------------------------------------------------------------------

    my $opts    = ref $_[0] ? shift : {@_};

    $opts->{table}      ||= 'comm_apps';
    $opts->{mode}       ||= 'edit'; # edit/search type forms
    $opts->{tags}       ||= GT::Template->tags;
    $opts->{template}   ||= 'user_form_edit.html';
    $opts->{t} ||= $CFG->{system_template_set};

    my $tags    = GT::Template->tags;

    my $apps = $DB->table($opts->{table})->select->fetchall_hashref;
    my $html = '';
    my $status = comm_language('ADMIN_APPS_STATUS');
    require Community::Apps;

    my $search_def = {
        form_names  => [qw( = <> )],
        form_values => [ split /\|/, comm_language( 'ADMIN_DB_FILTER_RADIO' ) ]
    };

    foreach my $app (@$apps) {
        if ($opts->{admin}) {
            my $col  = 'app_' . $app->{app_keyword};
            my $name = $DB->table('comm_users')->cols->{$col}->{form_display} || $col;

            my $select = Community::Web::SSI::ssi_form_control({
                    name => $col,
                    form_type => 'select',
                    def  => {
                        form_values => [
                            comm_language('ADMIN_APPS_STATUS_NOTCREATED'),
                            comm_language('ADMIN_APPS_STATUS_DISABLED'),
                            comm_language('ADMIN_APPS_STATUS_ENABLED'),
                        ],
                        form_names => [ 0, 1, 2 ]
                    },
                    value => $opts->{tags}{$col},
                    blank => ( $opts->{mode} eq 'search' )
            });
            $CFG->{title}      = $name." ".$status;
            $CFG->{input_html} = $$select;
            $html .= GT::Template->parse($CFG->{path_private}.'/templates/'.$opts->{t}.'/'.$opts->{template}, $CFG);
        }
        unless ( $opts->{mode} eq 'search' ) {
            $html .= Community::Apps::run($app, 'signup_form', $opts);
        }
    }
    if ($IN->param('do') eq 'ssi_apps_form') {
        print $IN->header() unless ($IN->param('noheaders'));
        print $html;
    }
    else {
        return \$html;
    }
}